---
title: '[2024년 11월] 서비스 이용약관 개정 변경 안내'
category: 공지사항
tags:
  - 공지사항
searchTags:
  - 서비스이용약관
  - 이용약관
datetime: 2024-11-04T03:44:53.773Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.\
2024년 11월 11일 아래와 같이 서비스 이용약관이 변경됨을 사전 안내 드립니다.

- 공고일 : 2024.11.04(월)
- 시행일 : 2024.11.11(월)

<Highlight text="변경내용" />

<Accordion title="▶ 제 4조 약관의 명시, 효력과 개정" image="https://help.portone.io/uploads/포트원소식/이용약관 제 4조 11월.png" />

<Accordion title="▶ 제 9조 이용요금의 청구 및 지급" image="https://help.portone.io/uploads/포트원소식/9조 이용요금의 청구 및 지급.png" />

<Accordion title="▶ 제 23조 원 페이먼트 인프라(One Payment Infra) 서비스 이용요금" image="https://help.portone.io/uploads/포트원소식/제 23조.png" />

<Accordion title="▶ 제 24조 유료플랜 전환" image="https://help.portone.io/uploads/포트원소식/제 24조.png" />

<Accordion title="▶ 제 25조 유료플랜 이용요금의 계산 " image="https://help.portone.io/uploads/포트원소식/제 25조.png" />

<Accordion title="▶ 제 27조 유료플랜 이용요금에 대한 이의신청 및 반환 " image="https://help.portone.io/uploads/포트원소식/제 27조.png" />

<Accordion title="▶ 제 28조 유료플랜 약정할인 위약금" image="https://help.portone.io/uploads/포트원소식/제 28조.png" />

> 현재 버전 보러 가기

[코리아포트원 서비스이용약관(개정일:2024.09.02)](https://terms.portone.io/?_gl=1*17qk47v*_gcl_au*NDcyNjE2NTQ0LjE3MjkwNDY3Nzg.*_ga*MTQzNTc5MTIyMi4xNzIxMTg2MTIx*_ga_PD0FDL16NZ*MTczMDY5OTQ5NC4xMzkuMS4xNzMwNzAwMDAwLjYwLjAuMA..)
